//----------------------------------------------------------------------------
// 
//	file: hsvrgb.cc
// 
//	function: convert hsv to rgb and vice versa 
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Tue Jan  5 02:18:29 CST 1999
// 
//	$Revision: 1.1 $ $Date: 1999/02/09 07:42:25 $
//	$Log: hsvrgb.cc,v $
//	Revision 1.1  1999/02/09 07:42:25  yschoe
//	Initial revision
//
//
//----------------------------------------------------------------------------

#include "hsvrgb.h"

// From jbednar's lissom2.0 code, ppm_draw.c
//----------------------------------------------------------------------------
/* Convert a color specified in HSV to RGB */
/* HSV values are specified in the range [0,1] */
/* From _Computer_Graphics_, 2nd Ed., Foley et al, 1990 */
/* Except Hue modified to lie in [0,1] instead of [0,360] */
void hsvrgb::hsv2rgb(REAL h, REAL s, REAL v,
	     int *r, int *g, int *b) {

  int    j;
  REAL rd, gd, bd;
  REAL f, p, q, T;
  REAL hue;

  /* convert HSV back to RGB */
  if (h==NOHUE || s==0.0) { rd = v;  gd = v;  bd = v; }
  else {
    /* Ensure bounds are met */
    if (s>1.0) s = 1.0;
    if (v>1.0) v = 1.0;
    /* hue ranges [0,6) */
    if (h >= 1.0 || h < 0.0) hue = 0.0;
    else        hue = h * 6.0;

    j = (int) floor(hue);
    if (j<0) j=0;          /* either h or floor seem to go neg on some sys */
    f = hue - j;
    p = v * (1-s);
    q = v * (1 - (s*f));
    T = v * (1 - (s*(1 - f)));

    switch (j) {
    case 0:  rd = v;  gd = T;  bd = p;  break;
    case 1:  rd = q;  gd = v;  bd = p;  break;
    case 2:  rd = p;  gd = v;  bd = T;  break;
    case 3:  rd = p;  gd = q;  bd = v;  break;
    case 4:  rd = T;  gd = p;  bd = v;  break;
    case 5:  rd = v;  gd = p;  bd = q;  break;
    default: rd = v;  gd = T;  bd = p;  break;  /* never happen */
    }
  }

  *r   = (int)floor((rd * 255) + 0.5);
  *g = (int)floor((gd * 255) + 0.5);
  *b  = (int)floor((bd * 255) + 0.5);

}

