//----------------------------------------------------------------------------
// 
//	file: tool_window.h   : ABSTRACT class
// 
//	function: provide basic buttons, scalebars, for child window(s)
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Tue Jul  7 07:02:29 CDT 1998
// 
//	$Revision: 1.5 $ $Date: 1999/02/09 07:42:25 $
//	$Log: tool_window.h,v $
//	Revision 1.5  1999/02/09 07:42:25  yschoe
//	test tool_window::BRelease_CB
//
//	Revision 1.4  1998/10/26 04:00:45  yschoe
//	fixed bug in destructor -- buttons were being deleted even when they
//	were not allocated in the beginning (with addbutton==0 at the constructor
//	call)
//
//	Revision 1.3  1998/10/05 19:48:46  yschoe
//	added a couple of buttons.
//
//	Revision 1.2  1998/09/04 03:36:37  yschoe
//	fixed all warnings generated by -Wall
//
//	Revision 1.1  1998/07/23 01:07:05  yschoe
//	jul22 stable version (except netlayer)
//
//
//----------------------------------------------------------------------------
#ifndef __TOOL_WINDOW_H
#define __TOOL_WINDOW_H

#include <window.h>
#include "real.h"

#define	MAX_G	20		// max number of gadgets per category

enum ToolType {SCROLL,CALLBACK,UNMAP};	// Tool types

class	tool_window : public main_window {
 
  int   button_flag; // set when buttons are added
  int	unmapped;
  int	num_sbars;
  REAL	old_sb_value[MAX_G];

  scrollbar	*sbar[MAX_G]; // default scroll bar : at most MAX_G
  callback_button *cback[MAX_G]; // default callback button : at most MAX_G

  callback_button *refresh_button; // refresh button
  unmap_button    *close_button; // refresh button

  virtual void	sbar_callback(tool_window *tw); // default scroll bar callback
  virtual void  cback_callback(); // default cback callback
  virtual void	init(int add_buttons); // init buttons
  virtual void  refresh(); // refresh display
  //virtual void  ClientMsg_CB(XClientMessageEvent); // close event

public:

  REAL	*sb_value[MAX_G]; // value of the scroll bar -- to be used by callbacks.

	tool_window(char *name, int w, int h, int x, int y, int add_buttons=0);
       ~tool_window();
  void 	toggle(); // run this to map the window.

  virtual void add_sbar(void (*cback_func)(), int width, int height, 
	int x, int y, double start, double stop, double initial,
        char *fmt_str);
  virtual void add_cback() {};
  virtual void BRelease_CB(XButtonEvent ev);

};

#endif
