#!/usr/bin/perl

$usage = "analyze-or-cog <orfile> <cogfile> <trajectoryfile> <thresh> [<step>=1]\n";

if ($#ARGV < 3) {
	print $usage;
	exit;
}

$orfile = $ARGV[0];
$cogfile = $ARGV[1];
$trajfile = $ARGV[2];
$thresh = $ARGV[3];

if ($#ARGV == 4) {
	$step=$ARGV[4];
} else {
	$step = 1;
}

# read orfile
open(FP,$orfile);
$k=0;
while (<FP>) {
  chop;
  @tmprow = split(/[\s]+/);
  for ($i=0; $i<= $#tmprow; ++$i) {
	$ormat[$k][$i] = $tmprow[$i];
  }
  $k++;
}
close(FP);

$rowsize = $k;

$cols = $#tmprow;

# read cogfile
open(FP,$cogfile);
$k=0;
while (<FP>) {
  chop;
  @tmprow = split(/[\s]+/);
  for ($i=0; $i<= $#tmprow; ++$i) {
	($x,$y) = split(/:/,$tmprow[$i]);
	$cogx[$k][$i] = $x;
	$cogy[$k][$i] = $y;
  }
  $k++;
}
close(FP);

# read trajfile
open(FP,$trajfile);
$k=0;
while (<FP>) {
  chop;
  ($x,$y) = split(/[\s]+/);
  $traj[$k][0] = $x;
  $traj[$k][1] = $y;
  $k++;
}
close(FP);

$samples = $k;

# go through given row and print out or-diff vs. distance
for ($r=$step; $r<$samples; $r+=$step) {

	  $row = $traj[$r][0];
	  $col = $traj[$r][1];

	  $prevrow = $traj[$r-$step][0];
	  $prevcol= $traj[$r-$step][1];

	  # or gradient;
	  $mx = &max($ormat[$row][$col],$ormat[$prevrow][$prevcol]);
	  $mn = &min($ormat[$row][$col],$ormat[$prevrow][$prevcol]);

	  $ordiff = $mx-$mn;
	  if ($ordiff > 0.5) {
		$ordiff = 1.0-$ordiff;
	  }
 	  $ordiff *=180;
	  # $ordiff = $ormat[$row][$i]-$ormat[$row][$i+$dist];
	  $d   = sqrt(($cogx[$row][$col]-$cogx[$prevrow][$prevcol])**2+
			 ($cogy[$row][$col]-$cogy[$prevrow][$prevcol])**2);
	  if ($d>$thresh) {
		next;
	  }
	  print "$ordiff $d\n";
}
  

sub min {

  my ($x,$y) = @_;

  if ($x>$y) {
	return $y;
  } else {
	return $x;
  }
}

sub max {

  my ($x,$y) = @_;

  if ($x>$y) {
	return $x;
  } else {
	return $y;
  }
}
