#!/usr/bin/wish

if {[llength $argv] <= 0} {
  puts "usage: feel.tcl <size> <zoom> <ppm_filename> <or_filename>"
  exit
}

# Load image file : ppm or gif
set size [lindex $argv 0]
set zoom [lindex $argv 1]
image create photo MAP -file "[lindex $argv 2]"
image create photo ZoomMAP 
ZoomMAP copy MAP -zoom $zoom $zoom

# Load orientation
set fp [open [lindex $argv 3]]
for {set i 0} {$i<$size} {incr i} {

  set line [gets $fp]
  set cols [split $line " "]
  for {set j 0} {$j<[expr [llength $cols]-1]} {incr j} {
	set or(${j}-${i}) [expr [lindex $cols $j]*180.0]
  }
}

for {set j 0} {$j<[expr [llength $cols]-1]} {incr j} {
	set or(${j}--1) "Out of range"
}
for {set i 0} {$i<$size} {incr i} {
	set max [llength $cols]
	set or(${size}-$i) "Out of range"
}

close $fp

# Create display window label
label .map -image ZoomMAP
pack .map -side top -padx 10 -pady 10
set datstr {[expr %x/$zoom],[expr $size-%y/$zoom-1]}
set pressed 0
bind .map <ButtonPress-1> { set pressed 1 }
bind .map <ButtonRelease-1> { set pressed 0 }
bind .map <Button-1> \
	{set pressed 1; set xc [expr %x/$zoom]; \
	 set yc [expr $size-%y/$zoom-1]; \
	 set yc_screen [expr %y/$zoom]; \
	 set cur "$xc $yc"; \
	 ZoomMAP put \#000000 -to [expr $xc*$zoom] \
		[expr $yc_screen*$zoom] \
		[expr $xc*$zoom + $zoom] \
		[expr $yc_screen*$zoom+$zoom]; \
	 update; \
	 puts $cur; flush stdout}
bind .map <Motion> \
  { if { $pressed == 0 } { set xc [expr %x/$zoom]; \
	   set yc [expr $size-%y/$zoom-1]; \
	   set cur $xc,$yc,$or($xc-$yc); \
	} \ 
    if { $pressed == 1 } { set xc [expr %x/$zoom]; \
	 set yc [expr $size-%y/$zoom-1]; \
	 set yc_screen [expr %y/$zoom]; \
	 set cur "$xc $yc"; \
	 ZoomMAP put \#000000 -to [expr $xc*$zoom] \
		[expr $yc_screen*$zoom] \
		[expr $xc*$zoom + $zoom] \
		[expr $yc_screen*$zoom+$zoom]; \
	 update; \
	 puts $cur; flush stdout} \
   }

# Create Coordinate display window
label .coord -textvariable cur -relief sunken \
	-foreground green -background black -font lucidasans-24
set cur "Coordinates"
pack .coord -side top -padx 20 -pady 10 -fill x

# Add quit button
button .clear -command { puts "\n* cleared *";  \
	ZoomMAP copy MAP -zoom $zoom $zoom \
	} -text "Clear"
pack .clear -side top -padx 10 -pady 10

button .quit -command { puts " "; exit } -text "Quit"
pack .quit -side top -padx 10 -pady 10


