%  function ff = huegrad(filename)
function ff = huegrad(filename)

    %% Extract hue into a .pgm file (requires ppmtohue program)
    huefilename=strcat(filename,".hue");
    system (strcat("ppmtohue ",filename," > ",huefilename));

    %% Read in the hue
    im = readpgm(huefilename);

    % assume that the or pref matrix "im" contains 
    % values in the range [0.0..1.0].
    [r,c]=size(im); 
    % so, normalize it to [0.0..1.0]
    x=min(vec(im)); y=max(vec(im));
    im = (im.-x)/(y-x);

    % get the 1st-difference for x and y 
    dx = diff(im,1);
    dx=dx(1:r-1,1:c-1); 

    dy=diff(im',1)';
    dy=dy(1:r-1,1:c-1); 

    % First convert negative angle to 180+(neg_angle), an equivalent
    % positive angle: this is the same as a sawtooth function.
    dx = dx - floor(dx);
    dy = dy - floor(dy);

    % Then, increase as gradient reachs 90\degree, and decrease from 
    % there on to % 180\degree
    dx = -abs(dx.-0.5) + 0.5;
    dy = -abs(dy.-0.5) + 0.5;

    ff=sqrt(dx.^2+dy.^2);
    imagesc_save((cos(dx*2*pi)+cos(dy*2*pi)),strcat(filename,".gradient"));

endfunction

