#!/usr/bin/wish

global E nV screen_w screen_h cols rows zoom

set zoom 8

#----------------------------------------------------------------------------
# 	plotnet: plot c.o.g.s net 
#----------------------------------------------------------------------------
proc plotnet { } {

	global E nV screen_w screen_h cols rows
	
 	set granx [expr $screen_w / $cols];
 	set grany [expr $screen_h / $rows];
	set length $granx

	for {set i 0} {$i<$rows} {incr i} {
	    for {set j 0} {$j<$cols} {incr j} {

		if {$nV($i-$j)>0.0} {

			set cx [expr $j*$granx]
			set cy [expr $i*$grany]

			set theta [expr $E($i-$j)-1]

			set rad_theta [expr $theta*3.141592/18.0]
			set offsetx [expr $length * cos($rad_theta)]
			set offsety [expr $length * sin($rad_theta)]

			.misc.net create line   \
				[expr $cx-$offsetx/2.0] \
				[expr $cy+$offsety/2.0] \
				[expr $cx+$offsetx/2.0] \
				[expr $cy-$offsety/2.0] \
				-fill \#000000 -width 1 
		}
	    }
	}
}


#----------------------------------------------------------------------------
#
# 	MAIN:
#
#----------------------------------------------------------------------------
if {[llength $argv] <= 1} {
  puts "usage: edgelines.tcl <Efile> <nVfile> \[<zoom:default 8>\]"
  exit
}

if {[llength $argv] == 3} {
	set zoom [lindex $argv 2]
	puts "zoom: $zoom"
}

#----------------------------------------
# 1. Load E data
#----------------------------------------
set fp [open [lindex $argv 0]]

set max_e 0
set idx 0

#--------------------
# skip octave comments
#--------------------
set line [gets $fp]
set line [gets $fp]
set line [gets $fp]

#--------------------
# get rows
#--------------------
set line [gets $fp]
set rows [lindex [split $line " "] 2]
puts "rows: $rows"

#--------------------
# get columns
#--------------------
set line [gets $fp]
set cols [lindex [split $line " "] 2]
puts "cols: $cols"

#--------------------
# get data
#--------------------
set j 0

while {![eof $fp]} {
  
  set line [gets $fp]

  if {[eof $fp]} {
		break
  }

  set column_data [split $line " "]

  for {set i 0} {$i<$cols} {incr i} {
	set E($j-$i) [lindex $column_data [expr $i+1]]
  }

  incr j
}
close $fp

#----------------------------------------
# 2. Load nV data
#----------------------------------------
set fp [open [lindex $argv 1]]

set max_e 0
set idx 0

#--------------------
# skip octave comments
#--------------------
set line [gets $fp]
set line [gets $fp]
set line [gets $fp]

#--------------------
# get rows
#--------------------
set line [gets $fp]
set rows [lindex [split $line " "] 2]
puts "rows: $rows"

#--------------------
# get columns
#--------------------
set line [gets $fp]
set cols [lindex [split $line " "] 2]
puts "cols: $cols"

#--------------------
# get data
#--------------------
set j 0

while {![eof $fp]} {
  
  set line [gets $fp]

  if {[eof $fp]} {
		break
  }

  set column_data [split $line " "]

  for {set i 0} {$i<$cols} {incr i} {
	set nV($j-$i) [lindex $column_data [expr $i+1]]
  }

  incr j
}
close $fp

#----------------------------------------
# 2. Create polar line display window
#----------------------------------------
frame .misc -relief ridge; pack .misc -padx 10 -pady 10

set screen_w [expr $cols * $zoom]
set screen_h [expr $rows * $zoom]

canvas .misc.net -relief sunken -borderwidth 1 -background white \
	-width $screen_w -height $screen_h;
pack .misc.net -side left -padx 10 -pady 5 ; 

button .psdump -command { \
        .misc.net postscript -file edgelines.ps ; \
        } -text "PS Dump"
pack .psdump -side left

button .quit -command { exit } -text "Quit"
pack .quit -side top -padx 10 -pady 10

plotnet
