#!/usr/bin/perl

$usage = <<'EOF';
usage: txttopdf.pl [-t <title>] [-f <fontsize>] [-d <date>] [-a <author>] <txtfile>

	converts a plain text file to a latex formatted document.
	
	<fontsize>: 11, 10, etc.

	output: a formatted PDF file.

	caution: overwrites <txtfile>.tex

EOF

require "getopts.pl";
&Getopts('t:d:a:f:');

if ($#ARGV != 0) {
	print $usage;
	exit;
}

$ifname = $ARGV[0];
$ofname = $ARGV[0].".tex";

if (-e $ofname) {
	print "txttopdf.pl: file $ofname exists. Aborting.\n";
	exit;
}

open(OFP,"> $ofname") || die "txttopdf.pl: cannot open $ofname for writing.\n";
open(IFP,$ifname) || die "txttopdf.pl: cannot open $ifname for reading.\n";

$mktitle = ($opt_a||$opt_d||$opt_t)?"\\maketitle\n":"\n";

$fsize = ($opt_f)?($opt_f."pt"):"12pt";

print OFP <<EOF;
\\documentclass[$fsize]{article}
\\usepackage{nnonecolumn}
\\usepackage{times}
\\input{nnmacros}
\\date{$opt_d}
\\author{$opt_a}
\\title{$opt_t}
\\begin{document}
$mktitle
EOF
while (<IFP>) {
	print OFP;
}
close(IFP);

print OFP "\\end{document}\n";

close(OFP);
	
`pdflatex $ofname; acroread $ifname.pdf`;
`rm $ofname`;


